@@ -17,11 +17,17 @@
 # pylint: enable=line-too-long
 # pylint: disable=g-import-not-at-top,g-bad-import-order,wrong-import-position
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 from packaging import version
 
-from disaggregators.disaggregation_modules import DisaggregationModule, DisaggregationModuleFactory
+from disaggregators.disaggregation_modules import (
+    CustomDisaggregator,
+    DisaggregationModule,
+    DisaggregationModuleConfig,
+    DisaggregationModuleFactory,
+    DisaggregationModuleLabels,
+)
 
 from .disaggregator import Disaggregator
 
